Package: tbea
Title: Pre- And Post-Processing in Bayesian Evolutionary Analyses
Version: 1.7.0
Authors@R: c(person("Gustavo A.", "Ballen", email = "gustavo.a.ballen@gmail.com", role = c("aut", "cre")), 
    person("Sandra", "Reinales", email = "spreinalesl@gmail.com", role = c("aut")))
Description: Functions are provided for prior specification in divergence time
    estimation using fossils as well as other kinds of data. It
    provides tools for interacting with the input and output of Bayesian
    platforms in evolutionary biology such as 'BEAST2', 'MrBayes', 'RevBayes',
    or 'MCMCTree'.
    It Implements a simple measure similarity between probability
    density functions for comparing prior and
    posterior Bayesian densities, as well as code for calculating the
    combination of distributions using conflation of Hill (2008). Functions for estimating the
    origination time in collections of distributions using the x-intercept (e.g., Draper and Smith, 1998) and
    stratigraphic intervals (Marshall 2010) are also available.
    Hill, T. 2008. "Conflations of probability distributions". Transactions of the American Mathematical Society, 363:3351-3372. <doi:10.48550/arXiv.0808.1808>,
    Draper, N. R. and Smith, H. 1998. "Applied Regression Analysis". 1--706. Wiley Interscience, New York. <DOI:10.1002/9781118625590>,
    Marshall, C. R. 2010. "Using confidence intervals to quantify the uncertainty in the end-points of stratigraphic ranges". Quantitative Methods in Paleobiology, 291--316. <DOI:10.1017/S1089332600001911>.
Depends: R (>= 3.5.0)
Imports: ape, Rfit, boot, graphics, stats, utils, coda
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
URL: https://github.com/gaballench/tbea,
        https://gaballench.github.io/tbea/
BugReports: https://github.com/gaballench/tbea/issues
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, Kendall
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-08-19 18:18:46 UTC; balleng
Author: Gustavo A. Ballen [aut, cre],
  Sandra Reinales [aut]
Maintainer: Gustavo A. Ballen <gustavo.a.ballen@gmail.com>
Repository: CRAN
Date/Publication: 2025-08-19 19:10:02 UTC
Built: R 4.6.0; ; 2026-04-27 20:46:53 UTC; unix
