# Generated by roxygen2: do not edit by hand

export(c_truncauchy)
export(concatNexus)
export(conflate)
export(crossplot)
export(density_fun)
export(fasta2nexus)
export(findParams)
export(lognormalBeast)
export(measureSimil)
export(mswd.test)
export(quantile_conflation)
export(stratCI)
export(summaryBrlen)
export(table2nexus)
export(tnt2newick)
export(topoFreq)
export(xintercept)
importFrom(Rfit,rfit)
importFrom(ape,dist.topo)
importFrom(ape,makeNodeLabel)
importFrom(ape,root)
importFrom(ape,unroot)
importFrom(boot,boot)
importFrom(coda,HPDinterval)
importFrom(coda,mcmc)
importFrom(graphics,abline)
importFrom(graphics,curve)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(stats,approxfun)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,density)
importFrom(stats,dlnorm)
importFrom(stats,ecdf)
importFrom(stats,hclust)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(utils,read.delim)
importFrom(utils,write.table)
